@@ -4,7 +4,7 @@
 #       Massachusetts Institute of Technology.
 # written by Olivier Thereaux <ot@w3.org> for W3C
 #
-# $Id: Basic.pm,v 1.9 2004/08/16 02:12:09 ot Exp $
+# $Id: Basic.pm,v 1.12 2004/11/12 07:10:47 ot Exp $
 
 package W3C::LogValidator::Basic;
 use strict;
@@ -16,7 +16,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = sprintf "%d.%03d",q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d",q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/;
 
 
 ###########################
@@ -57,7 +57,7 @@ sub trim_uris
 		$exclude_regexp =~ s/\//\\\//g ;
 		@exclude_areas = split(" ", $exclude_regexp);
 	}
-	else { print "nothing to exclude" if ($verbose >2);}
+	else { print "nothing to exclude\n" if ($verbose >2);}
         my $uri;
         while ($uri = shift)
         {
@@ -168,7 +168,7 @@ __END__
 
 =head1 NAME
 
-W3C::LogValidator::Basic
+W3C::LogValidator::Basic - [W3C Log Validator] Sort Web server log entries by popularity (hits)
 
 =head1 SYNOPSIS
 
@@ -233,7 +233,7 @@ Returns a result hash. Keys for this hash are:
 
 =head1 BUGS
 
-Public bug-tracking interface at L<http://www.w3.org/Bugs/Public/>
+Public bug-tracking interface at http://www.w3.org/Bugs/Public/
 
 
 =head1 AUTHOR
