@@ -4,7 +4,7 @@
 #       Massachusetts Institute of Technology.
 # written by olivier Thereaux <ot@w3.org> for W3C
 #
-# $Id: CSSValidator.pm,v 1.10 2004/08/16 02:12:09 ot Exp $
+# $Id: CSSValidator.pm,v 1.13 2004/11/12 07:10:47 ot Exp $
 
 package W3C::LogValidator::CSSValidator;
 use strict;
@@ -17,7 +17,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = sprintf "%d.%03d",q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/;
+our $VERSION = sprintf "%d.%03d",q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/;
 
 
 ###########################
@@ -125,7 +125,7 @@ sub trim_uris
             $exclude_regexp =~ s/\//\\\//g ;
             @excluded_areas = split(" ", $exclude_regexp);
         }
-        else { print "nothing to exclude" if ($verbose >2);}
+        else { print "nothing to exclude\n" if ($verbose >2);}
         my $uri;
         while ($uri = shift)
         {
@@ -338,7 +338,7 @@ __END__
 
 =head1 NAME
 
-W3C::LogValidator::CSSValidator - Validates CSS style sheets from Web Server logs
+W3C::LogValidator::CSSValidator - [W3C Log Validator] Batch validation of CSS style sheets (using the W3C CSS validator)
 
 =head1 SYNOPSIS
 
@@ -425,7 +425,7 @@ Resets all validation variables to 'undef'. In effect, prepares the processing m
 
 =head1 BUGS
 
-Public bug-tracking interface at L<http://www.w3.org/Bugs/Public/>
+Public bug-tracking interface at http://www.w3.org/Bugs/Public/
 
 
 
