@@ -4,7 +4,7 @@
 #       Massachusetts Institute of Technology.
 # written by Matthieu Faure <matthieu@faure.nom.fr> for W3C
 # maintained by olivier Thereaux <ot@w3.org> and Matthieu Faure <matthieu@faure.nom.fr>
-# SurveyEngine.pm v0.1 2004/05/17
+# $Id: SurveyEngine.pm,v 1.10 2004/11/12 07:10:47 ot Exp $
 
 package W3C::LogValidator::SurveyEngine;
 use strict;
@@ -15,7 +15,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
-our $VERSION = '0.1';
+our $VERSION = sprintf "%d.%03d",q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/;
 
 
 ###########################
@@ -30,7 +30,7 @@ sub new
 	my $proto = shift;
 	my $class = ref($proto) || $proto;
 	# mandatory vars for the API
-	$self->{URIS}	= undef;
+	@{$self->{URIs}} = undef;
 	# internal stuff here
 	# $self->{FOO} = undef;
 	
@@ -55,6 +55,14 @@ sub new
 }
 
 
+sub uris
+{
+	my $self = shift;
+	if (@_) { @{$self->{URIs}} = @_ }
+	return @{$self->{URIs}};
+}
+
+
 sub auth_ext
 {
 	my $self=shift;
@@ -62,7 +70,53 @@ sub auth_ext
 	return $self->{AUTH_EXT};
 }
 
+sub trim_uris 
+{
+        my $self = shift;
+        my @authorized_extensions = split(" ", $self->auth_ext);
+        my @trimmed_uris;
+        my $exclude_regexp = "";
+        my @excluded_areas;
+        $exclude_regexp = $config{ExcludeAreas};
+        if ($exclude_regexp){
+            $exclude_regexp =~ s/\//\\\//g ;
+            @excluded_areas = split(" ", $exclude_regexp);
+        }
+        else { print "nothing to exclude\n" if ($verbose >2);}
+        my $uri;
+        while ($uri = shift)
+        {
+                my $uri_ext = "";
+                my $match = 0;
+                if ($uri =~ /(\.[0-9a-zA-Z]+)$/)
+                {
+                   $uri_ext = $1;
+                }
+                elsif ($uri =~ /\/$/) { $uri_ext = "/";}
+                foreach my $ext (@authorized_extensions)
+                {
+                    if ($ext eq $uri_ext) { $match = 1; }
+                }
+                if ($match)
+                {
+                  foreach my $area (@excluded_areas)
+                  {
+                    if ($uri =~ /$area/)
+                    {
+                        my $slasharea = $area;
+                        $slasharea =~ s/\\\//\//g;
+                        $slasharea =~ s/\\././g;
+                        print "Ignoring $uri matching $slasharea \n" if ($verbose > 2) ;
+                        $match = 0;
+                    }
 
+                  }
+                }
+
+                push @trimmed_uris,$uri if ($match);
+        }
+        return @trimmed_uris;
+}
 
 #########################################
 # Actual subroutine to check the list of uris #
@@ -84,14 +138,24 @@ sub process_list
 
 
     print "Now Using the SurveyEngine module...\n" if $verbose;
+    my %hits;
+    my @uris;
     use URI::Escape;
     use LWP::UserAgent;
-    use DB_File;
-    my $tmp_file = $config{tmpfile};
-    my %hits;
-    tie (%hits, 'DB_File', "$tmp_file", O_RDONLY) ||
-      die ("Cannot create or open $tmp_file");
-    my @uris = sort { $hits{$b} <=> $hits{$a} } keys %hits;
+    if (defined ($config{tmpfile}))
+	{
+		use DB_File; 
+		my $tmp_file = $config{tmpfile};
+		tie (%hits, 'DB_File', "$tmp_file", O_RDONLY) || 
+		    die ("Cannot create or open $tmp_file");
+		@uris = sort { $hits{$b} <=> $hits{$a} } keys %hits;
+	}
+    elsif ($self->uris())
+	{
+		@uris = $self->uris();
+		foreach my $uri (@uris) { $hits{$uri} = 0 }
+	}
+    @uris = sort { $hits{$b} <=> $hits{$a} } keys %hits;
 					
     my @result_head;
     #push @result_head, "Hits";
@@ -112,22 +176,7 @@ sub process_list
     my $localDate = "$year-$mon-$mday" ;
     my $census = 0;
 
-    my @trimmed_uris;
-    foreach my $uri (@uris)
-	{
-		my @authorized_extensions = split(" ", $self->auth_ext);
-		foreach my $ext (@authorized_extensions)
-		{
-			if ($uri=~ /$ext$/ )
-			{ 
-				push @trimmed_uris,$uri;
-			#	print "$uri accepted" if ($verbose >2); #debug
-			 }
-			#else { print "$uri left out" if ($verbose >2);} # debug
-			
-		}
-	}
-    @uris = @trimmed_uris;
+    @uris = $self->trim_uris(@uris);
 
     while ((@uris) and  (($census < $max_documents) or (!$max_documents)) )
     {
@@ -217,8 +266,10 @@ sub process_list
     my $intro_str = "Here are the $census most popular documents surveyed for $name on .";
     print "Done!\n" if $verbose;
     #print "Result: @result \n" if $verbose;
-    untie %hits;
-	
+    if (defined ($config{tmpfile}))
+    {
+	untie %hits;
+    }
     # Here is what the module will return. The hash will be sent to 
     # the output module
 
@@ -242,22 +293,83 @@ package W3C::LogValidator::SurveyEngine;
 
 __END__
 
-=head1 SurveyEngine
+=head1 NAME
 
-W3C::LogValidator::SurveyEngine - Processing module for the Log Validator to run websites validity surveys
+W3C::LogValidator::SurveyEngine - [W3C Log Validator] Generic Web site validity/quality survey engine
 
 =head1 SYNOPSIS
 
-Module to run websites validity surveys
+  use  W3C::LogValidator::SurveyEngine;
+  my %config = ("verbose" => 2);
+  my $validator = W3C::LogValidator::SurveyEngine->new(\%config);
+  $validator->uris('http://www.w3.org/Overview.html', 'http://www.yahoo.com/index.html');
+  my %results = $validator->process_list;
+
 
 =head1 DESCRIPTION
 
-This module is part of the W3C::LogValidator suite, and ....
+This module is part of the W3C::LogValidator suite, and processes a list of URIs in order
+to produce a validity/quality survey.
+
+This module is experimental.
+
+=head1 API
+
+=head2 Constructor
+
+=over 2
+
+=item $val = W3C::LogValidator::SurveyEngine->new
+
+Constructs a new C<W3C::LogValidator::SurveyEngine> processor.  
+
+You might pass it a configuration hash reference (see L<W3C::LogValidator/config_module> and L<W3C::LogValidator::Config>)
+
+  $validator = W3C::LogValidator::SurveyEngine->new(\%config);  
+
+=back
+
+-head2 General methods
+
+=over 4
+
+=item $val->process_list
+
+Processes a list of sorted URIs through different quality tools to produce a survey of their quality/validity
+
+The list can be set C<uris>. If the $val was given a config has when constructed, and if the has has a "tmpfile" key, C<process_list> will try to read this file as a hash of URIs and "hits" (popularity) with L<DB_File>.
+
+Returns a result hash. Keys for this hash are: 
+
+
+  name (string): the name of the module, i.e "HTMLValidator"
+  intro (string): introduction to the processing results
+  thead (array): headers of the results table
+  trows (array of arrays): rows of the results table
+  outro (string): conclusion of the processing results
+
+
+=item $val->trim_uris 
+
+Given a list of URIs of documents to process, returns a subset of this list containing the URIs of documents the module supposedly can handle.
+The decision is made based on file extensions (see C<auth_ext>) and the ExcludeAreas configuration setting.
+
+
+=item $val->auth_ext
+
+Returns the file extensions (space separated entries in a string) supported by the Module.
+Public method accessing $self->{AUTH_EXT}, itself coming from either the AuthorizedExtensions configuration setting, or a default value
+
+=back
+
+
 
 =head1 AUTHOR
 
 Matthieu Faure  <matthieu@faure.nom.fr>
 
+Maintained by olivier Thereaux <ot@w3.org> for W3C
+
 =head1 SEE ALSO
 
 W3C::LogValidator::LogProcessor, perl(1).
